
{% macro frontend_nav_link(link) %}
    <li{% if link.active %} class=active{% endif %}>
        <a href="{{ url_for(link.endpoint,**kwargs) }}">{{ link.text }}</a>
    </li>
{% endmacro %}

{% macro render_frontend_nav(link_list,title) %}
    <div class=header>
        <ul class="nav nav-pills pull-right">
            {% for link in link_list %}
                {{ frontend_nav_link(link) }}
            {% endfor %}
        </ul>
        <h2 class=" page-header text-muted">{{ title|title }}</h3>
    </div>
{% endmacro %}


